@@ -1,5 +1,4 @@
 import csv
-import time
 from pathlib import Path
 from typing import Union
 from urllib.parse import urlencode, urljoin
@@ -7,9 +6,13 @@ from urllib.parse import urlencode, urljoin
 import requests
 
 from ..models import Interval, Time
+from ..utils import RateLimiter
 from .base import Source
 
 
+rate_limiter = RateLimiter(calls_per_seconds=2.0)
+
+
 class GateioSpotOHLCSource(Source):
     base_url = "https://api.gateio.ws/api/v4/"
     limit = 500
@@ -31,8 +34,6 @@ class GateioSpotOHLCSource(Source):
 
         self.symbol = symbol
 
-        self._latest_request_time_ms = None
-
     @property
     def slug(self):
         return (
@@ -40,13 +41,6 @@ class GateioSpotOHLCSource(Source):
         )
 
     def load(self, ts: Time, path: Path) -> (Time, Time, bool):
-        time_ms = int(time.monotonic() * 1000)
-        if (
-            self._latest_request_time_ms
-            and time_ms - self._latest_request_time_ms < 200
-        ):
-            time.sleep(0.2)
-
         start_ts = ts.block_ts(self.interval * self.limit)
 
         rows = self._request(
@@ -62,8 +56,6 @@ class GateioSpotOHLCSource(Source):
 
         self._write(rows, path=path)
 
-        self._latest_request_time_ms = time_ms
-
         return (
             Time(rows[0][0]),
             Time(rows[-1][0]),
@@ -85,10 +77,14 @@ class GateioSpotOHLCSource(Source):
         if data_str:
             url = "?".join([url, data_str])
 
-        response = requests.get(
-            url,
-            headers={"Accept": "application/json", "Content-Type": "application/json"},
-        )
+        with rate_limiter():
+            response = requests.get(
+                url,
+                headers={
+                    "Accept": "application/json",
+                    "Content-Type": "application/json",
+                },
+            )
 
         assert response.status_code == 200, response.content
 
